@@ -13,6 +13,7 @@ import qualified Data.Set as Set
 import qualified Data.Map as Map
 import Data.List (isInfixOf, isSuffixOf)
 import Data.Maybe (fromMaybe)
+import Data.CallStack
 
 import System.Directory (getDirectoryContents)
 import System.FilePath ((</>), replaceExtension)
@@ -20,7 +21,7 @@ import System.FilePath ((</>), replaceExtension)
 import Block
 import Inline
 
-check :: Text -> Text -> Expectation
+check :: HasCallStack => Text -> Text -> Expectation
 check html md = renderHtml (markdown def md) `shouldBe` html
 
 checkSet :: MarkdownSettings -> Text -> Text -> Expectation
